<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// S
	'sites_description' => 'سايت‌ها و مشترك‌سازي‌ها در اسپسپ (خصوصي و همگاني)',
	'sites_slogan' => 'مديريت سايت‌ها و مشترك‌سازي در اسپيپ',
];
